@@ -7,6 +7,7 @@ import logging
 import urllib
 import urllib2
 
+from tiddlyweb.control import readable_tiddlers_by_bag
 from tiddlyweb.store import StoreError, NoUserError
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.tiddler import Tiddler
@@ -20,48 +21,7 @@ from tiddlywebplugins.tiddlyspace.spaces import space_uri
 from tiddlywebplugins.tiddlyspace.web import determine_host
 from tiddlyweb.wikitext import render_wikitext
 from tiddlywebplugins.utils import get_store
-
-
-HOST_META_TEMPLATE = """<?xml version="1.0" encoding="UTF-8"?>
-<XRD xmlns="http://docs.oasis-open.org/ns/xri/xrd-1.0" xmlns:hm="http://host-meta.net/xrd/1.0">
-<hm:Host xmlns="http://host-meta.net/xrd/1.0">%(host)s</hm:Host>
-<Link rel="lrdd" template="%(server_host)s/webfinger?q={uri}">
-<Title>Resource Descriptor</Title>
-</Link>
-</XRD>
-"""
-
-
-WEBFINGER_TEMPLATE = """<?xml version="1.0"?>
-<XRD xmlns="http://docs.oasis-open.org/ns/xri/xrd-1.0">
-<Subject>acct:%(username)s@%(host)s</Subject>
-<Alias>%(server_host)s/profiles/%(username)s</Alias>
-<Link rel="http://webfinger.net/rel/profile-page"
-      href="%(server_host)s/profiles/%(username)s"
-      type="text/html"/>
-<Link rel="describedby"
-      href="%(server_host)s/profiles/%(username)s"
-      type="text/html"/>
-<Link rel="http://schemas.google.com/g/2010#updates-from"
-      href="%(server_host)s/profiles/%(username)s.atom"
-      type="application/atom+xml"/>
-</XRD>
-"""
-
-PROFILE_TEMPLATE = """
-<div class="tiddler">
-<div id="hcard-%(username)s" class="vcard" style="float:right">
-<div class="fn"><a href="%(space_uri)s" class="url">%(username)s</a></div>
-<a href="%(space_uri)s" title="space link"><img style="float:right" src="%(avatar_path)s" alt="avatar" class="photo"></img></a>
-</div>
-%(profile)s
-</div>
-<div>
-<ul id="tiddlers" class="listing">
-%(tiddlers)s
-</div>
-</ul>
-"""
+from tiddlywebplugins.tiddlyspace.template import send_template
 
 
 def add_profile_routes(selector):
@@ -120,11 +80,6 @@ def html_profile(environ, start_response):
 
     activity_feed = profile_atom_url(environ, username)
 
-    environ['tiddlyweb.links'] = [
-           '<link rel="alternate" type="application/atom+xml"'
-           'title="Atom activity feed" href="%s" />'
-           % activity_feed]
-
     profile_tiddler = Tiddler('profile', '%s_public' % username)
     try:
         profile_tiddler = store.get(profile_tiddler)
@@ -134,37 +89,21 @@ def html_profile(environ, start_response):
     profile_text = render_wikitext(profile_tiddler, environ)
 
     tiddlers = store.search(_search_string(username))
-    tiddlers_list = []
-
-    # XXX this bag_readable loop is copied from
-    # tiddlyweb.web.handler.search:get, it should be factored
-    # out of there for resue
-    bag_readable = {}
-    for tiddler in tiddlers:
-        try:
-            if bag_readable[tiddler.bag]:
-                tiddlers_list.append(_tiddler_in_list(tiddler))
-        except KeyError:
-            bag = Bag(tiddler.bag)
-            bag = store.get(bag)
-            try:
-                bag.policy.allows(usersign, 'read')
-                tiddlers_list.append(_tiddler_in_list(tiddler))
-                bag_readable[tiddler.bag] = True
-            except(ForbiddenError, UserRequiredError):
-                bag_readable[tiddler.bag] = False
-
-    profile_tiddlers = '\n'.join(tiddlers_list)
+    tiddlers_list = readable_tiddlers_by_bag(store, tiddlers, usersign)
 
     avatar_path = '/recipes/%s_public/tiddlers/SiteIcon' % username
 
     start_response('200 OK', [
         ('Content-Type', 'text/html; charset=UTF-8')])
 
-    environ['tiddlyweb.title'] = 'Profile for %s' % username
-    return [PROFILE_TEMPLATE % {'username': username,
-        'avatar_path': avatar_path, 'space_uri': space_uri(environ, username),
-        'profile': profile_text, 'tiddlers': profile_tiddlers}]
+    return send_template(environ, 'tsprofile.html', {
+        'css': '/bags/common/tiddlers/profile.css',
+        'username': username,
+        'activity_feed': activity_feed,
+        'avatar_path': avatar_path,
+        'space_uri': space_uri(environ, username),
+        'profile': profile_text,
+        'tiddlers': tiddlers_list})
 
 
 def host_meta(environ, start_response):
@@ -179,11 +118,13 @@ def host_meta(environ, start_response):
     start_response('200 OK', [
         ('Content-Type', 'application/xrd+xml')])
 
-    return [HOST_META_TEMPLATE % {'host': http_host, 'server_host':
-        server_base_url(environ)}]
+    return send_template(environ, 'hostmeta.xml', {'host': http_host})
 
 
 def profile_atom_url(environ, username):
+    """
+    The atom url of a profile, given a username.
+    """
     return (server_host_url(environ) +
             '/profiles/%s.atom' % encode_name(username))
 
@@ -208,18 +149,27 @@ def webfinger(environ, start_response):
     start_response('200 OK', [
         ('Content-Type', 'application/xrd+xml')])
 
-    return [WEBFINGER_TEMPLATE % {'username': username,
-        'host': http_host, 'server_host': server_base_url(environ)}]
+    return send_template(environ, 'webfinger.xml', {
+        'username': username,
+        'host': http_host})
 
 
 try:
     from tiddlywebplugins.dispatcher.listener import Listener as BaseListener
+
     class Listener(BaseListener):
+        """
+        Define a dispatcher listener that sends a PuSH ping.
+        """
 
         TUBE = 'pushping'
         STORE = None
 
         def _act(self, job):
+            """
+            Do the action of sending the ping when a job (a tiddler) 
+            is received from the queue.
+            """
             if not self.STORE:
                 self.STORE = get_store(self.config)
             info = self._unpack(job)
@@ -228,12 +178,16 @@ try:
             try:
                 self.STORE.get(tiddler)
             except StoreError:
-                return None #  Tiddler's not there, no need to notify
+                return None  # Tiddler's not there, no need to notify
             user = tiddler.modifier
             if self._user_has_profile(user):
                 self._send_ping(user)
 
         def _user_has_profile(self, user):
+            """
+            True if the user has opted in for profiles by creating
+            a profile tiddler in their public bag.
+            """
             try:
                 tiddler = Tiddler('profile', '%s_public' % user)
                 self.STORE.get(tiddler)
@@ -242,10 +196,13 @@ try:
             return True
 
         def _send_ping(self, user):
+            """
+            Formulate and send the PuSH ping.
+            """
             data = {
                     'hub.mode': 'publish',
-                    'hub.url': profile_atom_url({'tiddlyweb.config': self.config},
-                        user),
+                    'hub.url': profile_atom_url(
+                        {'tiddlyweb.config': self.config}, user),
                     }
 
             try:
@@ -257,16 +214,19 @@ try:
             try:
                 response = urllib2.urlopen(target, encoded_data)
                 status = response.getcode()
-                logging.warn('sent %s to %s got %s', encoded_data, target, status)
+                logging.warn('sent %s to %s got %s',
+                        encoded_data, target, status)
                 if status != '204':
                     logging.warn('non 204 response from hub: %s', status)
             except urllib2.HTTPError, exc:
                 if exc.code != 204:
-                    logging.warn('urlopen errored with %s when publishing to hub',
+                    logging.warn(
+                            'urlopen errored with %s when publishing to hub',
                             exc)
             except urllib2.URLError, exc:
-                logging,warn('urlopen errored with %s when publishing to hub', exc)
-            except Attribute, exc:
+                logging.warn(
+                        'urlopen errored with %s when publishing to hub', exc)
+            except AttributeError, exc:
                 logging.warn('error when publishing to hub: %s, %s',
                         exc, response.info())
 except ImportError:
@@ -279,9 +239,3 @@ def _search_string(username):
     the recent tiddlers for this username.
     """
     return 'modifier:%s _limit:20' % username
-
-
-def _tiddler_in_list(tiddler):
-    return ('<li><a href="/bags/%s/tiddlers/%s">%s</a></li>'
-            % (encode_name(tiddler.bag), encode_name(tiddler.title),
-                tiddler.title))
